@@ -86,7 +86,7 @@ def _createFields( runTime, mesh, g ):
     
     ext_Info() << "Creating turbulence model\n" << nl
     from Foam import incompressible
-    turbulence = incompressible.turbulenceModel.New( U, phi, laminarTransport )
+    turbulence = incompressible.RASModel.New( U, phi, laminarTransport )
     
     pRefCell = 0
     pRefValue = 0.0
@@ -205,7 +205,7 @@ def main_standalone( argc, argv ):
     adjustTimeStep, maxCo, maxDeltaT = readTimeControls( runTime )
     
     from Foam.finiteVolume.cfdTools.general.include import CourantNo
-    CoNum, meanCoNum, velMag = CourantNo( mesh, phi, runTime )
+    CoNum, meanCoNum = CourantNo( mesh, phi, runTime )
     
     from Foam.finiteVolume.cfdTools.general.include import setInitialDeltaT
     runTime = setInitialDeltaT( runTime, adjustTimeStep, maxCo, maxDeltaT, CoNum )
@@ -223,7 +223,7 @@ def main_standalone( argc, argv ):
         piso, nCorr, nNonOrthCorr, momentumPredictor, transonic, nOuterCorr = readPISOControls( mesh )
         
         from Foam.finiteVolume.cfdTools.general.include import CourantNo
-        CoNum, meanCoNum, velMag = CourantNo( mesh, phi, runTime )
+        CoNum, meanCoNum = CourantNo( mesh, phi, runTime )
         
         from Foam.finiteVolume.cfdTools.general.include import setDeltaT
         runTime = setDeltaT( runTime, adjustTimeStep, maxCo, maxDeltaT, CoNum )
@@ -253,9 +253,9 @@ def main_standalone( argc, argv ):
 
 
 #--------------------------------------------------------------------------------------
-from Foam import FOAM_BRANCH_VERSION
+from Foam import FOAM_REF_VERSION
 import sys, os
-if FOAM_BRANCH_VERSION( "dev", ">=", "010600" ):
+if FOAM_REF_VERSION( "==", "010600" ):
    if __name__ == "__main__" :
       argv = sys.argv
       os._exit( main_standalone( len( argv ), argv ) )
